@@ -2,8 +2,7 @@ import click
 
 from pymobiledevice3.cli.cli_common import Command
 from pymobiledevice3.lockdown import LockdownClient
-from pymobiledevice3.services.afc import AfcShell
-from pymobiledevice3.services.crash_reports import CrashReports
+from pymobiledevice3.services.crash_reports import CrashReportsManager, CrashReportsShell
 
 
 @click.group()
@@ -21,7 +20,7 @@ def crash():
 @crash.command('clear', cls=Command)
 def crash_clear(lockdown: LockdownClient):
     """ clear(/remove) all crash reports """
-    CrashReports(lockdown).clear()
+    CrashReportsManager(lockdown).clear()
 
 
 @crash.command('pull', cls=Command)
@@ -32,13 +31,13 @@ def crash_pull(lockdown: LockdownClient, out, remote_file, erase):
     """ pull all crash reports """
     if remote_file is None:
         remote_file = '/'
-    CrashReports(lockdown).pull(out, remote_file, erase)
+    CrashReportsManager(lockdown).pull(out, remote_file, erase)
 
 
 @crash.command('shell', cls=Command)
 def crash_shell(lockdown: LockdownClient):
     """ start an afc shell """
-    AfcShell(lockdown=lockdown, service_name=CrashReports.COPY_MOBILE_NAME).cmdloop()
+    CrashReportsShell(lockdown=lockdown).cmdloop()
 
 
 @crash.command('ls', cls=Command)
@@ -48,14 +47,14 @@ def crash_ls(lockdown: LockdownClient, remote_file, depth):
     """ List  """
     if remote_file is None:
         remote_file = '/'
-    for path in CrashReports(lockdown).ls(remote_file, depth):
+    for path in CrashReportsManager(lockdown).ls(remote_file, depth):
         print(path)
 
 
 @crash.command('flush', cls=Command)
 def crash_mover_flush(lockdown: LockdownClient):
     """ trigger com.apple.crashreportmover to flush all products into CrashReports directory """
-    CrashReports(lockdown).flush()
+    CrashReportsManager(lockdown).flush()
 
 
 @crash.command('watch', cls=Command)
@@ -63,7 +62,7 @@ def crash_mover_flush(lockdown: LockdownClient):
 @click.option('-r', '--raw', is_flag=True)
 def crash_mover_watch(lockdown: LockdownClient, name, raw):
     """ watch for crash report generation """
-    for crash_report in CrashReports(lockdown).watch(name=name, raw=raw):
+    for crash_report in CrashReportsManager(lockdown).watch(name=name, raw=raw):
         print(crash_report)
 
 
@@ -73,4 +72,4 @@ def crash_mover_watch(lockdown: LockdownClient, name, raw):
 def crash_sysdiagnose(lockdown: LockdownClient, out, erase):
     """ get a sysdiagnose archive from device (requires user interaction) """
     print('Press Power+VolUp+VolDown for 0.215 seconds')
-    CrashReports(lockdown).get_new_sysdiagnose(out, erase=erase)
+    CrashReportsManager(lockdown).get_new_sysdiagnose(out, erase=erase)
