@@ -1,3 +1,6 @@
+from typing import Union
+
+from pymobiledevice3.exceptions import NotificationTimeoutError
 from pymobiledevice3.lockdown import LockdownClient
 from pymobiledevice3.services.base_service import BaseService
 
@@ -6,12 +9,15 @@ class NotificationProxyService(BaseService):
     SERVICE_NAME = 'com.apple.mobile.notification_proxy'
     INSECURE_SERVICE_NAME = 'com.apple.mobile.insecure_notification_proxy'
 
-    def __init__(self, lockdown: LockdownClient, insecure=False):
+    def __init__(self, lockdown: LockdownClient, insecure=False, timeout: Union[float, int] = None):
         if insecure:
             super().__init__(lockdown, self.INSECURE_SERVICE_NAME)
         else:
             super().__init__(lockdown, self.SERVICE_NAME)
 
+        if timeout is not None:
+            self.service.socket.settimeout(timeout)
+
     def notify_post(self, name: str):
         """ Send notification to the device's notification_proxy. """
         self.service.send_plist({'Command': 'PostNotification',
@@ -19,10 +25,13 @@ class NotificationProxyService(BaseService):
 
     def notify_register_dispatch(self, name: str):
         """ Tells the device to send a notification on the specified event. """
-        self.logger.info('Observing %s', name)
+        self.logger.info(f'Observing {name}')
         self.service.send_plist({'Command': 'ObserveNotification',
                                  'Name': name})
 
     def receive_notification(self):
         while True:
-            yield self.service.recv_plist()
+            try:
+                yield self.service.recv_plist()
+            except TimeoutError as e:
+                raise NotificationTimeoutError from e
