@@ -1,6 +1,6 @@
 import logging
-import socket
 import select
+import socket
 import threading
 
 from pymobiledevice3.lockdown import LockdownClient
@@ -109,11 +109,12 @@ class TcpForwarder:
         local_connection.setblocking(False)
 
         try:
-            service_connection = ServiceConnection.create(self.lockdown.udid, self.dst_port,
-                                                          connection_type=self.lockdown.usbmux_device.connection_type)
+            service_connection = ServiceConnection.create(
+                self.lockdown.udid, self.dst_port, connection_type=self.lockdown.usbmux_device.connection_type)
 
             if self.enable_ssl:
-                service_connection.ssl_start(self.lockdown.ssl_file, self.lockdown.ssl_file)
+                with self.lockdown.ssl_file() as ssl_file:
+                    service_connection.ssl_start(ssl_file)
 
             remote_connection = service_connection.socket
         except ConnectionFailedError:
